
# setup
setwd("~/Desktop/schools") # set working directory
library("ggplot2") # load ggplot library

# read files
admit = read.csv("data/admit.csv", header=TRUE)
enrollment = read.csv("data/enrollment.csv", header=TRUE)
grad4 = read.csv("data/graduation-4yr.csv", header=TRUE)
grad6 = read.csv("data/graduation-6yr.csv", header=TRUE)

# look at enrollment data frame 
enrollment

# or just Hampshire
enrollment$Hampshire.College

# get summary stats
summary(enrollment)

# scatterplot (using base R)
plot(enrollment$year, enrollment$Hampshire.College)

# histogram (not particularly useful for these data)
hist(enrollment$Hampshire.College, breaks = 5)





# working with ggplot
# -------------------

# scatterplot (using ggplot)
# theme_minimal() turns off most fancy formatting
ggplot(data = enrollment) + geom_point(mapping = aes(x = enrollment$year, y = enrollment$Hampshire.College)) + theme_minimal()

# scatterplot, now two schools
ggplot(data = enrollment) + 
	geom_point(mapping = aes(x = enrollment$year, y = enrollment$Hampshire.College)) + 
	geom_point(mapping = aes(x = enrollment$year, y = enrollment$Williams.College)) + 
	theme_minimal()

# scatterplot, with colors
ggplot(data = enrollment) + 
	geom_point(mapping = aes(x = enrollment$year, y = enrollment$Hampshire.College), color = "red") + 
	geom_point(mapping = aes(x = enrollment$year, y = enrollment$Williams.College), color = "purple") + 
	theme_minimal()

# lines instead
ggplot(data = enrollment) + 
	geom_line(mapping = aes(x = enrollment$year, y = enrollment$Hampshire.College), color = "red") + 
	geom_line(mapping = aes(x = enrollment$year, y = enrollment$Williams.College), color = "purple") + 
	ylim(0, 2500) +
	scale_x_continuous(breaks = seq(2007, 2018, 2)) +
	theme_minimal()

# combining lines with points, just Hampshire 
# (not the most sophisticated solution, but direct)
ggplot(data = enrollment) + 
	geom_point(mapping = aes(x = enrollment$year, y = enrollment$Hampshire.College), color = "red") + 
	geom_line(mapping = aes(x = enrollment$year, y = enrollment$Hampshire.College), color = "red") + 
	ylim(0, 2500) +
	scale_x_continuous(breaks = seq(2007, 2018, 2)) +
	theme_minimal()

# bar chart (*not* geom_bar!)
ggplot(data = enrollment) + 
	geom_col(mapping = aes(x = enrollment$year, y = enrollment$Hampshire.College), color = "gray", fill = "gray", width = 0.8) + 
	ylim(0, 2500) +
	scale_x_continuous(breaks = seq(2007, 2018, 2)) +
	theme_minimal()

# graduation rates
ggplot(data = enrollment) + 
	geom_point(mapping = aes(x = grad4$year, y = grad4$Hampshire.College), color = "red") + 
	geom_line(mapping = aes(x = grad4$year, y = grad4$Hampshire.College), color = "red") + 
	geom_point(mapping = aes(x = grad6$year, y = grad6$Hampshire.College), color = "blue") + 
	geom_line(mapping = aes(x = grad6$year, y = grad6$Hampshire.College), color = "blue") + 
	ylim(0, 100) +
	scale_x_continuous(breaks = seq(2007, 2018, 2)) +
	theme_minimal()
